==> openshift-model-installer-6.7.2-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/MachinePoolBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolBuilder extends MachinePoolFluentImpl<MachinePoolBuilder> implements VisitableBuilder<MachinePool,MachinePoolBuilder>{
  public MachinePoolBuilder() {
    this(false);
  }
  public MachinePoolBuilder(Boolean validationEnabled) {
    this(new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance) {
    this(fluent, instance, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAffinityGroupsNames(instance.getAffinityGroupsNames());
      fluent.withAutoPinningPolicy(instance.getAutoPinningPolicy());
      fluent.withCpu(instance.getCpu());
      fluent.withHugepages(instance.getHugepages());
      fluent.withInstanceTypeID(instance.getInstanceTypeID());
      fluent.withMemoryMB(instance.getMemoryMB());
      fluent.withOsDisk(instance.getOsDisk());
      fluent.withVmType(instance.getVmType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolBuilder(MachinePool instance) {
    this(instance,false);
  }
  public MachinePoolBuilder(MachinePool instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAffinityGroupsNames(instance.getAffinityGroupsNames());
      this.withAutoPinningPolicy(instance.getAutoPinningPolicy());
      this.withCpu(instance.getCpu());
      this.withHugepages(instance.getHugepages());
      this.withInstanceTypeID(instance.getInstanceTypeID());
      this.withMemoryMB(instance.getMemoryMB());
      this.withOsDisk(instance.getOsDisk());
      this.withVmType(instance.getVmType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachinePoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePool build() {
    MachinePool buildable = new MachinePool(fluent.getAffinityGroupsNames(),fluent.getAutoPinningPolicy(),fluent.getCpu(),fluent.getHugepages(),fluent.getInstanceTypeID(),fluent.getMemoryMB(),fluent.getOsDisk(),fluent.getVmType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-installer-6.8.0-sources.jar: io/fabric8/openshift/api/model/installer/ovirt/v1/MachinePoolBuilder.java <==
package io.fabric8.openshift.api.model.installer.ovirt.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachinePoolBuilder extends MachinePoolFluent<MachinePoolBuilder> implements VisitableBuilder<MachinePool,MachinePoolBuilder>{
  public MachinePoolBuilder() {
    this(false);
  }
  public MachinePoolBuilder(Boolean validationEnabled) {
    this(new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent) {
    this(fluent, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachinePool(), validationEnabled);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance) {
    this(fluent, instance, false);
  }
  public MachinePoolBuilder(MachinePoolFluent<?> fluent,MachinePool instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MachinePool());

    if (instance != null) {
      fluent.withAffinityGroupsNames(instance.getAffinityGroupsNames());
      fluent.withAutoPinningPolicy(instance.getAutoPinningPolicy());
      fluent.withClone(instance.getClone());
      fluent.withCpu(instance.getCpu());
      fluent.withFormat(instance.getFormat());
      fluent.withHugepages(instance.getHugepages());
      fluent.withInstanceTypeID(instance.getInstanceTypeID());
      fluent.withMemoryMB(instance.getMemoryMB());
      fluent.withOsDisk(instance.getOsDisk());
      fluent.withSparse(instance.getSparse());
      fluent.withVmType(instance.getVmType());
      fluent.withAffinityGroupsNames(instance.getAffinityGroupsNames());
      fluent.withAutoPinningPolicy(instance.getAutoPinningPolicy());
      fluent.withClone(instance.getClone());
      fluent.withCpu(instance.getCpu());
      fluent.withFormat(instance.getFormat());
      fluent.withHugepages(instance.getHugepages());
      fluent.withInstanceTypeID(instance.getInstanceTypeID());
      fluent.withMemoryMB(instance.getMemoryMB());
      fluent.withOsDisk(instance.getOsDisk());
      fluent.withSparse(instance.getSparse());
      fluent.withVmType(instance.getVmType());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MachinePoolBuilder(MachinePool instance) {
    this(instance,false);
  }
  public MachinePoolBuilder(MachinePool instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MachinePool());

    if (instance != null) {
      this.withAffinityGroupsNames(instance.getAffinityGroupsNames());
      this.withAutoPinningPolicy(instance.getAutoPinningPolicy());
      this.withClone(instance.getClone());
      this.withCpu(instance.getCpu());
      this.withFormat(instance.getFormat());
      this.withHugepages(instance.getHugepages());
      this.withInstanceTypeID(instance.getInstanceTypeID());
      this.withMemoryMB(instance.getMemoryMB());
      this.withOsDisk(instance.getOsDisk());
      this.withSparse(instance.getSparse());
      this.withVmType(instance.getVmType());
      this.withAffinityGroupsNames(instance.getAffinityGroupsNames());
      this.withAutoPinningPolicy(instance.getAutoPinningPolicy());
      this.withClone(instance.getClone());
      this.withCpu(instance.getCpu());
      this.withFormat(instance.getFormat());
      this.withHugepages(instance.getHugepages());
      this.withInstanceTypeID(instance.getInstanceTypeID());
      this.withMemoryMB(instance.getMemoryMB());
      this.withOsDisk(instance.getOsDisk());
      this.withSparse(instance.getSparse());
      this.withVmType(instance.getVmType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  MachinePoolFluent<?> fluent;
  Boolean validationEnabled;
  public MachinePool build() {
    MachinePool buildable = new MachinePool(fluent.getAffinityGroupsNames(),fluent.getAutoPinningPolicy(),fluent.getClone(),fluent.buildCpu(),fluent.getFormat(),fluent.getHugepages(),fluent.getInstanceTypeID(),fluent.getMemoryMB(),fluent.buildOsDisk(),fluent.getSparse(),fluent.getVmType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
